# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Weak dependencies require rpm 4.12 or later
%global have_weak_deps 0%{?fedora} > 20 || 0%{?rhel} > 7

Name:		perl-Exporter-Tiny
Version:	1.006002
Release:	1.%{__distinit}%{__distvers}
Summary:	An exporter with the features of Sub::Exporter but only core dependencies
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://exportertiny.github.io/
Source0:	https://cpan.metacpan.org/modules/by-module/Exporter/Exporter-Tiny-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.17
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Optional Functionality
# Note: Lexical::Var and Lexical::Sub both come from the perl-Lexical-Var package
# Not needed from 5.37.2 onwards, which have experimental lexical export support
# So we should be able to drop this (and the runtime dep) for F-38 later
BuildRequires:	perl(Lexical::Var)
# Test Suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More) >= 0.47
# Optional Tests
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::Warnings)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Carp)
%if %{have_weak_deps}
Recommends:	perl(Lexical::Var)
%else
Requires:	perl(Lexical::Var)
%endif

# Avoid doc-file dependency on perl(base)
%{?perl_default_filter}

%description
Exporter::Tiny supports many of Sub::Exporter's external-facing features
including renaming imported functions with the -as, -prefix and -suffix
options; explicit destinations with the into option; and alternative
installers with the installer option. But it's written in only about 40%%
as many lines of code and with zero non-core dependencies.

Its internal-facing interface is closer to Exporter.pm, with configuration
done through the @EXPORT, @EXPORT_OK and %%EXPORT_TAGS package variables.

Exporter::Tiny performs most of its internal duties (including resolution of
tag names to sub names, resolution of sub names to coderefs, and installation
of coderefs into the target package) as method calls, which means they can be
overridden to provide interesting behavior.

%prep
%setup -q -n Exporter-Tiny-%{version}

# Remove bundled modules Test::Fatal, Test::Requires, Test::Simple and Try::Tiny
rm -rv ./inc/
sed -i -e '/^inc\//d' MANIFEST

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license COPYRIGHT LICENSE
%doc Changes CREDITS examples/ NEWS README TODO
%{perl_vendorlib}/Exporter/
%{_mandir}/man3/Exporter::Tiny.3*
%{_mandir}/man3/Exporter::Tiny::Manual::Etc.3*
%{_mandir}/man3/Exporter::Tiny::Manual::Exporting.3*
%{_mandir}/man3/Exporter::Tiny::Manual::Importing.3*
%{_mandir}/man3/Exporter::Tiny::Manual::QuickStart.3*
%{_mandir}/man3/Exporter::Shiny.3*

%changelog
* Sun Apr  2 2023 Paul Howarth <paul@city-fan.org> - 1.006002-1
- Update to 1.006002
  Documentation
  - Link to Exporter::Almighty in pod
  - Update copyright dates
  Packaging
  - Set homepage in metadata to https://exportertiny.github.io

* Sun Mar 26 2023 Paul Howarth <paul@city-fan.org> - 1.006001-1
- Update to 1.006001
  Documentation
  - Don't mention Alt::Lexical::Var::ButSupportModernPerl in manual
  Packaging
  - No longer dynamically recommend Alt::Lexical::Var::ButSupportModernPerl

* Mon Nov 21 2022 Paul Howarth <paul@city-fan.org> - 1.006000-1
- Update to 1.006000
  - Introduced lexical exporter support on Perl 5.11.2+ using the Lexical::Var
    module
  - Refactored the Perl 5.37.2+ lexical exporter support

* Sat Oct 15 2022 Paul Howarth <paul@city-fan.org> - 1.004004-1
- Update to 1.004004
  - Minor corrections to QuickStart page in the manual

* Fri Sep 30 2022 Paul Howarth <paul@city-fan.org> - 1.004003-1
- Update to 1.004003
  Bug Fixes
  - If exporting non-CODE items that happen to have the same name as exported
    CODE items, their export was quietly being blocked; these exports should
    now work (GH#9)
  - Using ! with a tag now works; it was previously documented as working but
    not implemented (GH#8)

* Tue Sep 20 2022 Paul Howarth <paul@city-fan.org> - 1.004002-1
- Update to 1.004002
  - Fix for t/15nonhashvalue.t on old versions of Test::More that don't support
    'done_testing'

* Sat Sep 10 2022 Paul Howarth <paul@city-fan.org> - 1.004001-1
- Update to 1.004001
  - Fix handling of non-hashref references in import list

* Mon Aug 29 2022 Paul Howarth <paul@city-fan.org> - 1.004000-1
- Update to 1.004000
  - Provide an experimental '-lexical' export option on Perl 5.37.2+
  - Quote $1 when passing it as a parameter to a function (GH#7)
- Use SPDX-format license tag
- Use %%license unconditionally
- Package new NEWS file

* Fri Apr 24 2020 Paul Howarth <paul@city-fan.org> - 1.002002-1
- Update to 1.002002
  - Fix bug in handling regexps in import lists; Exporter::Tiny allowed regexps
    like /foo/i but not /foo/; having trailing flags is now optional! (GH#6)
  - Tests would fail if 'PERL5OPT=-Mfeature=:5.18' environment variable was set;
    this is because bareword '-default' was being interpreted as the Perl
    'default' keyword (GH#5)
- Unbundle newly-bundled test modules

* Wed Jun  5 2019 Paul Howarth <paul@city-fan.org> - 1.002001-3
- Perl 5.30 rebuild

* Wed Jul 18 2018 Paul Howarth <paul@city-fan.org> - 1.002001-1
- Update to 1.002001
  - Added support for generating and exporting non-code symbols such as $Foo,
    @Bar, and %%Baz
  - Improved test coverage, up from 88.78%% on coveralls.io to 96.74%%
- Switch upstream from search.cpan.org to metacpan.org
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Mon May 22 2017 Paul Howarth <paul@city-fan.org> - 1.000000-1
- Update to 1.000000
  - Repackage as 1.000000
- All shipped files are now GPL+ or Artistic
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Test::Warnings always available now

* Mon Jan 30 2017 Paul Howarth <paul@city-fan.org> - 0.044-1
- Update to 0.044
  - Support { -as => CODE } to programmatically rename functions
  - Restructure documentation

* Mon Jan  9 2017 Paul Howarth <paul@city-fan.org> - 0.042-7
- Test::Warnings now available back to Fedora 9

* Mon Aug 22 2016 Paul Howarth <paul@city-fan.org> - 0.042-6
- BR: perl-generators where available
- Simplify find command using -delete

* Fri Jun 26 2015 Paul Howarth <paul@city-fan.org> - 0.042-4
- Perl 5.22 rebuild

* Fri Mar  6 2015 Paul Howarth <paul@city-fan.org> - 0.042-2
- Correct license tagging (#1199491)

* Thu Oct  9 2014 Paul Howarth <paul@city-fan.org> - 0.042-1
- Update to 0.042
  - Add an 'unimport' feature
  - Option validation needs to happen after expanding tags
  - Housekeeping on %%TRACKED

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 0.040-1
- Update to 0.040
  - Document warning and error messages produced by Exporter::Tiny
  - Exporter::Tiny would previously cause B.pm to be loaded into memory any
    time it exported anything: it no longer does
  - No longer die when redefining locally defined subs
  - Warn when redefining any subs
- Use %%license where possible

* Fri Apr  4 2014 Paul Howarth <paul@city-fan.org> - 0.038-1
- Update to 0.038
  - Added: Support Exporter.pm's import negation syntax qw( !foo )
  - Added: Support Exporter.pm's regexp import syntax qw( /foo/ )
  - Fix minor error in documentation of generators
  - Improved handling of hashrefs of options passed to tags, and hashrefs of
    options found within %%EXPORT_TAGS arrayrefs
  - Only attempt to merge hashes if we're sure they're both really hashes!
- Drop %%defattr, redundant since rpm 4.4

* Thu Mar 13 2014 Paul Howarth <paul@city-fan.org> - 0.036-1
- Initial RPM version
